# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'ConnectorDefinitionConnector',
    'ConnectorDefinitionConnectorDefinitionVersion',
    'ConnectorDefinitionVersionConnector',
    'CoreDefinitionCore',
    'CoreDefinitionCoreDefinitionVersion',
    'CoreDefinitionVersionCore',
    'DeviceDefinitionDevice',
    'DeviceDefinitionDeviceDefinitionVersion',
    'DeviceDefinitionVersionDevice',
    'FunctionDefinitionDefaultConfig',
    'FunctionDefinitionEnvironment',
    'FunctionDefinitionExecution',
    'FunctionDefinitionFunction',
    'FunctionDefinitionFunctionConfiguration',
    'FunctionDefinitionFunctionDefinitionVersion',
    'FunctionDefinitionResourceAccessPolicy',
    'FunctionDefinitionRunAs',
    'FunctionDefinitionVersionDefaultConfig',
    'FunctionDefinitionVersionEnvironment',
    'FunctionDefinitionVersionExecution',
    'FunctionDefinitionVersionFunction',
    'FunctionDefinitionVersionFunctionConfiguration',
    'FunctionDefinitionVersionResourceAccessPolicy',
    'FunctionDefinitionVersionRunAs',
    'GroupGroupVersion',
    'LoggerDefinitionLogger',
    'LoggerDefinitionLoggerDefinitionVersion',
    'LoggerDefinitionVersionLogger',
    'ResourceDefinitionGroupOwnerSetting',
    'ResourceDefinitionLocalDeviceResourceData',
    'ResourceDefinitionLocalVolumeResourceData',
    'ResourceDefinitionResourceDataContainer',
    'ResourceDefinitionResourceDefinitionVersion',
    'ResourceDefinitionResourceDownloadOwnerSetting',
    'ResourceDefinitionResourceInstance',
    'ResourceDefinitionS3MachineLearningModelResourceData',
    'ResourceDefinitionSageMakerMachineLearningModelResourceData',
    'ResourceDefinitionSecretsManagerSecretResourceData',
    'ResourceDefinitionVersionGroupOwnerSetting',
    'ResourceDefinitionVersionLocalDeviceResourceData',
    'ResourceDefinitionVersionLocalVolumeResourceData',
    'ResourceDefinitionVersionResourceDataContainer',
    'ResourceDefinitionVersionResourceDownloadOwnerSetting',
    'ResourceDefinitionVersionResourceInstance',
    'ResourceDefinitionVersionS3MachineLearningModelResourceData',
    'ResourceDefinitionVersionSageMakerMachineLearningModelResourceData',
    'ResourceDefinitionVersionSecretsManagerSecretResourceData',
    'SubscriptionDefinitionSubscription',
    'SubscriptionDefinitionSubscriptionDefinitionVersion',
    'SubscriptionDefinitionVersionSubscription',
]

@pulumi.output_type
class ConnectorDefinitionConnector(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectorArn":
            suggest = "connector_arn"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectorDefinitionConnector. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectorDefinitionConnector.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectorDefinitionConnector.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 connector_arn: str,
                 id: str,
                 parameters: Optional[Any] = None):
        pulumi.set(__self__, "connector_arn", connector_arn)
        pulumi.set(__self__, "id", id)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)

    @property
    @pulumi.getter(name="connectorArn")
    def connector_arn(self) -> str:
        return pulumi.get(self, "connector_arn")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def parameters(self) -> Optional[Any]:
        return pulumi.get(self, "parameters")


@pulumi.output_type
class ConnectorDefinitionConnectorDefinitionVersion(dict):
    def __init__(__self__, *,
                 connectors: Sequence['outputs.ConnectorDefinitionConnector']):
        pulumi.set(__self__, "connectors", connectors)

    @property
    @pulumi.getter
    def connectors(self) -> Sequence['outputs.ConnectorDefinitionConnector']:
        return pulumi.get(self, "connectors")


@pulumi.output_type
class ConnectorDefinitionVersionConnector(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectorArn":
            suggest = "connector_arn"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectorDefinitionVersionConnector. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectorDefinitionVersionConnector.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectorDefinitionVersionConnector.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 connector_arn: str,
                 id: str,
                 parameters: Optional[Any] = None):
        pulumi.set(__self__, "connector_arn", connector_arn)
        pulumi.set(__self__, "id", id)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)

    @property
    @pulumi.getter(name="connectorArn")
    def connector_arn(self) -> str:
        return pulumi.get(self, "connector_arn")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def parameters(self) -> Optional[Any]:
        return pulumi.get(self, "parameters")


@pulumi.output_type
class CoreDefinitionCore(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "certificateArn":
            suggest = "certificate_arn"
        elif key == "thingArn":
            suggest = "thing_arn"
        elif key == "syncShadow":
            suggest = "sync_shadow"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CoreDefinitionCore. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CoreDefinitionCore.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CoreDefinitionCore.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 certificate_arn: str,
                 id: str,
                 thing_arn: str,
                 sync_shadow: Optional[bool] = None):
        pulumi.set(__self__, "certificate_arn", certificate_arn)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "thing_arn", thing_arn)
        if sync_shadow is not None:
            pulumi.set(__self__, "sync_shadow", sync_shadow)

    @property
    @pulumi.getter(name="certificateArn")
    def certificate_arn(self) -> str:
        return pulumi.get(self, "certificate_arn")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="thingArn")
    def thing_arn(self) -> str:
        return pulumi.get(self, "thing_arn")

    @property
    @pulumi.getter(name="syncShadow")
    def sync_shadow(self) -> Optional[bool]:
        return pulumi.get(self, "sync_shadow")


@pulumi.output_type
class CoreDefinitionCoreDefinitionVersion(dict):
    def __init__(__self__, *,
                 cores: Sequence['outputs.CoreDefinitionCore']):
        pulumi.set(__self__, "cores", cores)

    @property
    @pulumi.getter
    def cores(self) -> Sequence['outputs.CoreDefinitionCore']:
        return pulumi.get(self, "cores")


@pulumi.output_type
class CoreDefinitionVersionCore(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "certificateArn":
            suggest = "certificate_arn"
        elif key == "thingArn":
            suggest = "thing_arn"
        elif key == "syncShadow":
            suggest = "sync_shadow"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CoreDefinitionVersionCore. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CoreDefinitionVersionCore.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CoreDefinitionVersionCore.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 certificate_arn: str,
                 id: str,
                 thing_arn: str,
                 sync_shadow: Optional[bool] = None):
        pulumi.set(__self__, "certificate_arn", certificate_arn)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "thing_arn", thing_arn)
        if sync_shadow is not None:
            pulumi.set(__self__, "sync_shadow", sync_shadow)

    @property
    @pulumi.getter(name="certificateArn")
    def certificate_arn(self) -> str:
        return pulumi.get(self, "certificate_arn")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="thingArn")
    def thing_arn(self) -> str:
        return pulumi.get(self, "thing_arn")

    @property
    @pulumi.getter(name="syncShadow")
    def sync_shadow(self) -> Optional[bool]:
        return pulumi.get(self, "sync_shadow")


@pulumi.output_type
class DeviceDefinitionDevice(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "certificateArn":
            suggest = "certificate_arn"
        elif key == "thingArn":
            suggest = "thing_arn"
        elif key == "syncShadow":
            suggest = "sync_shadow"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeviceDefinitionDevice. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeviceDefinitionDevice.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeviceDefinitionDevice.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 certificate_arn: str,
                 id: str,
                 thing_arn: str,
                 sync_shadow: Optional[bool] = None):
        pulumi.set(__self__, "certificate_arn", certificate_arn)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "thing_arn", thing_arn)
        if sync_shadow is not None:
            pulumi.set(__self__, "sync_shadow", sync_shadow)

    @property
    @pulumi.getter(name="certificateArn")
    def certificate_arn(self) -> str:
        return pulumi.get(self, "certificate_arn")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="thingArn")
    def thing_arn(self) -> str:
        return pulumi.get(self, "thing_arn")

    @property
    @pulumi.getter(name="syncShadow")
    def sync_shadow(self) -> Optional[bool]:
        return pulumi.get(self, "sync_shadow")


@pulumi.output_type
class DeviceDefinitionDeviceDefinitionVersion(dict):
    def __init__(__self__, *,
                 devices: Sequence['outputs.DeviceDefinitionDevice']):
        pulumi.set(__self__, "devices", devices)

    @property
    @pulumi.getter
    def devices(self) -> Sequence['outputs.DeviceDefinitionDevice']:
        return pulumi.get(self, "devices")


@pulumi.output_type
class DeviceDefinitionVersionDevice(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "certificateArn":
            suggest = "certificate_arn"
        elif key == "thingArn":
            suggest = "thing_arn"
        elif key == "syncShadow":
            suggest = "sync_shadow"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeviceDefinitionVersionDevice. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeviceDefinitionVersionDevice.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeviceDefinitionVersionDevice.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 certificate_arn: str,
                 id: str,
                 thing_arn: str,
                 sync_shadow: Optional[bool] = None):
        pulumi.set(__self__, "certificate_arn", certificate_arn)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "thing_arn", thing_arn)
        if sync_shadow is not None:
            pulumi.set(__self__, "sync_shadow", sync_shadow)

    @property
    @pulumi.getter(name="certificateArn")
    def certificate_arn(self) -> str:
        return pulumi.get(self, "certificate_arn")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="thingArn")
    def thing_arn(self) -> str:
        return pulumi.get(self, "thing_arn")

    @property
    @pulumi.getter(name="syncShadow")
    def sync_shadow(self) -> Optional[bool]:
        return pulumi.get(self, "sync_shadow")


@pulumi.output_type
class FunctionDefinitionDefaultConfig(dict):
    def __init__(__self__, *,
                 execution: 'outputs.FunctionDefinitionExecution'):
        pulumi.set(__self__, "execution", execution)

    @property
    @pulumi.getter
    def execution(self) -> 'outputs.FunctionDefinitionExecution':
        return pulumi.get(self, "execution")


@pulumi.output_type
class FunctionDefinitionEnvironment(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accessSysfs":
            suggest = "access_sysfs"
        elif key == "resourceAccessPolicies":
            suggest = "resource_access_policies"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionDefinitionEnvironment. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionDefinitionEnvironment.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionDefinitionEnvironment.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 access_sysfs: Optional[bool] = None,
                 execution: Optional['outputs.FunctionDefinitionExecution'] = None,
                 resource_access_policies: Optional[Sequence['outputs.FunctionDefinitionResourceAccessPolicy']] = None,
                 variables: Optional[Any] = None):
        if access_sysfs is not None:
            pulumi.set(__self__, "access_sysfs", access_sysfs)
        if execution is not None:
            pulumi.set(__self__, "execution", execution)
        if resource_access_policies is not None:
            pulumi.set(__self__, "resource_access_policies", resource_access_policies)
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter(name="accessSysfs")
    def access_sysfs(self) -> Optional[bool]:
        return pulumi.get(self, "access_sysfs")

    @property
    @pulumi.getter
    def execution(self) -> Optional['outputs.FunctionDefinitionExecution']:
        return pulumi.get(self, "execution")

    @property
    @pulumi.getter(name="resourceAccessPolicies")
    def resource_access_policies(self) -> Optional[Sequence['outputs.FunctionDefinitionResourceAccessPolicy']]:
        return pulumi.get(self, "resource_access_policies")

    @property
    @pulumi.getter
    def variables(self) -> Optional[Any]:
        return pulumi.get(self, "variables")


@pulumi.output_type
class FunctionDefinitionExecution(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "isolationMode":
            suggest = "isolation_mode"
        elif key == "runAs":
            suggest = "run_as"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionDefinitionExecution. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionDefinitionExecution.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionDefinitionExecution.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 isolation_mode: Optional[str] = None,
                 run_as: Optional['outputs.FunctionDefinitionRunAs'] = None):
        if isolation_mode is not None:
            pulumi.set(__self__, "isolation_mode", isolation_mode)
        if run_as is not None:
            pulumi.set(__self__, "run_as", run_as)

    @property
    @pulumi.getter(name="isolationMode")
    def isolation_mode(self) -> Optional[str]:
        return pulumi.get(self, "isolation_mode")

    @property
    @pulumi.getter(name="runAs")
    def run_as(self) -> Optional['outputs.FunctionDefinitionRunAs']:
        return pulumi.get(self, "run_as")


@pulumi.output_type
class FunctionDefinitionFunction(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "functionArn":
            suggest = "function_arn"
        elif key == "functionConfiguration":
            suggest = "function_configuration"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionDefinitionFunction. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionDefinitionFunction.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionDefinitionFunction.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 function_arn: str,
                 function_configuration: 'outputs.FunctionDefinitionFunctionConfiguration',
                 id: str):
        pulumi.set(__self__, "function_arn", function_arn)
        pulumi.set(__self__, "function_configuration", function_configuration)
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="functionArn")
    def function_arn(self) -> str:
        return pulumi.get(self, "function_arn")

    @property
    @pulumi.getter(name="functionConfiguration")
    def function_configuration(self) -> 'outputs.FunctionDefinitionFunctionConfiguration':
        return pulumi.get(self, "function_configuration")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")


@pulumi.output_type
class FunctionDefinitionFunctionConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "encodingType":
            suggest = "encoding_type"
        elif key == "execArgs":
            suggest = "exec_args"
        elif key == "memorySize":
            suggest = "memory_size"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionDefinitionFunctionConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionDefinitionFunctionConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionDefinitionFunctionConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 encoding_type: Optional[str] = None,
                 environment: Optional['outputs.FunctionDefinitionEnvironment'] = None,
                 exec_args: Optional[str] = None,
                 executable: Optional[str] = None,
                 memory_size: Optional[int] = None,
                 pinned: Optional[bool] = None,
                 timeout: Optional[int] = None):
        if encoding_type is not None:
            pulumi.set(__self__, "encoding_type", encoding_type)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if exec_args is not None:
            pulumi.set(__self__, "exec_args", exec_args)
        if executable is not None:
            pulumi.set(__self__, "executable", executable)
        if memory_size is not None:
            pulumi.set(__self__, "memory_size", memory_size)
        if pinned is not None:
            pulumi.set(__self__, "pinned", pinned)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @property
    @pulumi.getter(name="encodingType")
    def encoding_type(self) -> Optional[str]:
        return pulumi.get(self, "encoding_type")

    @property
    @pulumi.getter
    def environment(self) -> Optional['outputs.FunctionDefinitionEnvironment']:
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter(name="execArgs")
    def exec_args(self) -> Optional[str]:
        return pulumi.get(self, "exec_args")

    @property
    @pulumi.getter
    def executable(self) -> Optional[str]:
        return pulumi.get(self, "executable")

    @property
    @pulumi.getter(name="memorySize")
    def memory_size(self) -> Optional[int]:
        return pulumi.get(self, "memory_size")

    @property
    @pulumi.getter
    def pinned(self) -> Optional[bool]:
        return pulumi.get(self, "pinned")

    @property
    @pulumi.getter
    def timeout(self) -> Optional[int]:
        return pulumi.get(self, "timeout")


@pulumi.output_type
class FunctionDefinitionFunctionDefinitionVersion(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultConfig":
            suggest = "default_config"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionDefinitionFunctionDefinitionVersion. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionDefinitionFunctionDefinitionVersion.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionDefinitionFunctionDefinitionVersion.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 functions: Sequence['outputs.FunctionDefinitionFunction'],
                 default_config: Optional['outputs.FunctionDefinitionDefaultConfig'] = None):
        pulumi.set(__self__, "functions", functions)
        if default_config is not None:
            pulumi.set(__self__, "default_config", default_config)

    @property
    @pulumi.getter
    def functions(self) -> Sequence['outputs.FunctionDefinitionFunction']:
        return pulumi.get(self, "functions")

    @property
    @pulumi.getter(name="defaultConfig")
    def default_config(self) -> Optional['outputs.FunctionDefinitionDefaultConfig']:
        return pulumi.get(self, "default_config")


@pulumi.output_type
class FunctionDefinitionResourceAccessPolicy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "resourceId":
            suggest = "resource_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionDefinitionResourceAccessPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionDefinitionResourceAccessPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionDefinitionResourceAccessPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 resource_id: str,
                 permission: Optional[str] = None):
        pulumi.set(__self__, "resource_id", resource_id)
        if permission is not None:
            pulumi.set(__self__, "permission", permission)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> str:
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter
    def permission(self) -> Optional[str]:
        return pulumi.get(self, "permission")


@pulumi.output_type
class FunctionDefinitionRunAs(dict):
    def __init__(__self__, *,
                 gid: Optional[int] = None,
                 uid: Optional[int] = None):
        if gid is not None:
            pulumi.set(__self__, "gid", gid)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)

    @property
    @pulumi.getter
    def gid(self) -> Optional[int]:
        return pulumi.get(self, "gid")

    @property
    @pulumi.getter
    def uid(self) -> Optional[int]:
        return pulumi.get(self, "uid")


@pulumi.output_type
class FunctionDefinitionVersionDefaultConfig(dict):
    def __init__(__self__, *,
                 execution: 'outputs.FunctionDefinitionVersionExecution'):
        pulumi.set(__self__, "execution", execution)

    @property
    @pulumi.getter
    def execution(self) -> 'outputs.FunctionDefinitionVersionExecution':
        return pulumi.get(self, "execution")


@pulumi.output_type
class FunctionDefinitionVersionEnvironment(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accessSysfs":
            suggest = "access_sysfs"
        elif key == "resourceAccessPolicies":
            suggest = "resource_access_policies"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionDefinitionVersionEnvironment. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionDefinitionVersionEnvironment.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionDefinitionVersionEnvironment.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 access_sysfs: Optional[bool] = None,
                 execution: Optional['outputs.FunctionDefinitionVersionExecution'] = None,
                 resource_access_policies: Optional[Sequence['outputs.FunctionDefinitionVersionResourceAccessPolicy']] = None,
                 variables: Optional[Any] = None):
        if access_sysfs is not None:
            pulumi.set(__self__, "access_sysfs", access_sysfs)
        if execution is not None:
            pulumi.set(__self__, "execution", execution)
        if resource_access_policies is not None:
            pulumi.set(__self__, "resource_access_policies", resource_access_policies)
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter(name="accessSysfs")
    def access_sysfs(self) -> Optional[bool]:
        return pulumi.get(self, "access_sysfs")

    @property
    @pulumi.getter
    def execution(self) -> Optional['outputs.FunctionDefinitionVersionExecution']:
        return pulumi.get(self, "execution")

    @property
    @pulumi.getter(name="resourceAccessPolicies")
    def resource_access_policies(self) -> Optional[Sequence['outputs.FunctionDefinitionVersionResourceAccessPolicy']]:
        return pulumi.get(self, "resource_access_policies")

    @property
    @pulumi.getter
    def variables(self) -> Optional[Any]:
        return pulumi.get(self, "variables")


@pulumi.output_type
class FunctionDefinitionVersionExecution(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "isolationMode":
            suggest = "isolation_mode"
        elif key == "runAs":
            suggest = "run_as"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionDefinitionVersionExecution. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionDefinitionVersionExecution.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionDefinitionVersionExecution.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 isolation_mode: Optional[str] = None,
                 run_as: Optional['outputs.FunctionDefinitionVersionRunAs'] = None):
        if isolation_mode is not None:
            pulumi.set(__self__, "isolation_mode", isolation_mode)
        if run_as is not None:
            pulumi.set(__self__, "run_as", run_as)

    @property
    @pulumi.getter(name="isolationMode")
    def isolation_mode(self) -> Optional[str]:
        return pulumi.get(self, "isolation_mode")

    @property
    @pulumi.getter(name="runAs")
    def run_as(self) -> Optional['outputs.FunctionDefinitionVersionRunAs']:
        return pulumi.get(self, "run_as")


@pulumi.output_type
class FunctionDefinitionVersionFunction(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "functionArn":
            suggest = "function_arn"
        elif key == "functionConfiguration":
            suggest = "function_configuration"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionDefinitionVersionFunction. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionDefinitionVersionFunction.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionDefinitionVersionFunction.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 function_arn: str,
                 function_configuration: 'outputs.FunctionDefinitionVersionFunctionConfiguration',
                 id: str):
        pulumi.set(__self__, "function_arn", function_arn)
        pulumi.set(__self__, "function_configuration", function_configuration)
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="functionArn")
    def function_arn(self) -> str:
        return pulumi.get(self, "function_arn")

    @property
    @pulumi.getter(name="functionConfiguration")
    def function_configuration(self) -> 'outputs.FunctionDefinitionVersionFunctionConfiguration':
        return pulumi.get(self, "function_configuration")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")


@pulumi.output_type
class FunctionDefinitionVersionFunctionConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "encodingType":
            suggest = "encoding_type"
        elif key == "execArgs":
            suggest = "exec_args"
        elif key == "memorySize":
            suggest = "memory_size"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionDefinitionVersionFunctionConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionDefinitionVersionFunctionConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionDefinitionVersionFunctionConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 encoding_type: Optional[str] = None,
                 environment: Optional['outputs.FunctionDefinitionVersionEnvironment'] = None,
                 exec_args: Optional[str] = None,
                 executable: Optional[str] = None,
                 memory_size: Optional[int] = None,
                 pinned: Optional[bool] = None,
                 timeout: Optional[int] = None):
        if encoding_type is not None:
            pulumi.set(__self__, "encoding_type", encoding_type)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if exec_args is not None:
            pulumi.set(__self__, "exec_args", exec_args)
        if executable is not None:
            pulumi.set(__self__, "executable", executable)
        if memory_size is not None:
            pulumi.set(__self__, "memory_size", memory_size)
        if pinned is not None:
            pulumi.set(__self__, "pinned", pinned)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @property
    @pulumi.getter(name="encodingType")
    def encoding_type(self) -> Optional[str]:
        return pulumi.get(self, "encoding_type")

    @property
    @pulumi.getter
    def environment(self) -> Optional['outputs.FunctionDefinitionVersionEnvironment']:
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter(name="execArgs")
    def exec_args(self) -> Optional[str]:
        return pulumi.get(self, "exec_args")

    @property
    @pulumi.getter
    def executable(self) -> Optional[str]:
        return pulumi.get(self, "executable")

    @property
    @pulumi.getter(name="memorySize")
    def memory_size(self) -> Optional[int]:
        return pulumi.get(self, "memory_size")

    @property
    @pulumi.getter
    def pinned(self) -> Optional[bool]:
        return pulumi.get(self, "pinned")

    @property
    @pulumi.getter
    def timeout(self) -> Optional[int]:
        return pulumi.get(self, "timeout")


@pulumi.output_type
class FunctionDefinitionVersionResourceAccessPolicy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "resourceId":
            suggest = "resource_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FunctionDefinitionVersionResourceAccessPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FunctionDefinitionVersionResourceAccessPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FunctionDefinitionVersionResourceAccessPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 resource_id: str,
                 permission: Optional[str] = None):
        pulumi.set(__self__, "resource_id", resource_id)
        if permission is not None:
            pulumi.set(__self__, "permission", permission)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> str:
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter
    def permission(self) -> Optional[str]:
        return pulumi.get(self, "permission")


@pulumi.output_type
class FunctionDefinitionVersionRunAs(dict):
    def __init__(__self__, *,
                 gid: Optional[int] = None,
                 uid: Optional[int] = None):
        if gid is not None:
            pulumi.set(__self__, "gid", gid)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)

    @property
    @pulumi.getter
    def gid(self) -> Optional[int]:
        return pulumi.get(self, "gid")

    @property
    @pulumi.getter
    def uid(self) -> Optional[int]:
        return pulumi.get(self, "uid")


@pulumi.output_type
class GroupGroupVersion(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectorDefinitionVersionArn":
            suggest = "connector_definition_version_arn"
        elif key == "coreDefinitionVersionArn":
            suggest = "core_definition_version_arn"
        elif key == "deviceDefinitionVersionArn":
            suggest = "device_definition_version_arn"
        elif key == "functionDefinitionVersionArn":
            suggest = "function_definition_version_arn"
        elif key == "loggerDefinitionVersionArn":
            suggest = "logger_definition_version_arn"
        elif key == "resourceDefinitionVersionArn":
            suggest = "resource_definition_version_arn"
        elif key == "subscriptionDefinitionVersionArn":
            suggest = "subscription_definition_version_arn"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GroupGroupVersion. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GroupGroupVersion.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GroupGroupVersion.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 connector_definition_version_arn: Optional[str] = None,
                 core_definition_version_arn: Optional[str] = None,
                 device_definition_version_arn: Optional[str] = None,
                 function_definition_version_arn: Optional[str] = None,
                 logger_definition_version_arn: Optional[str] = None,
                 resource_definition_version_arn: Optional[str] = None,
                 subscription_definition_version_arn: Optional[str] = None):
        if connector_definition_version_arn is not None:
            pulumi.set(__self__, "connector_definition_version_arn", connector_definition_version_arn)
        if core_definition_version_arn is not None:
            pulumi.set(__self__, "core_definition_version_arn", core_definition_version_arn)
        if device_definition_version_arn is not None:
            pulumi.set(__self__, "device_definition_version_arn", device_definition_version_arn)
        if function_definition_version_arn is not None:
            pulumi.set(__self__, "function_definition_version_arn", function_definition_version_arn)
        if logger_definition_version_arn is not None:
            pulumi.set(__self__, "logger_definition_version_arn", logger_definition_version_arn)
        if resource_definition_version_arn is not None:
            pulumi.set(__self__, "resource_definition_version_arn", resource_definition_version_arn)
        if subscription_definition_version_arn is not None:
            pulumi.set(__self__, "subscription_definition_version_arn", subscription_definition_version_arn)

    @property
    @pulumi.getter(name="connectorDefinitionVersionArn")
    def connector_definition_version_arn(self) -> Optional[str]:
        return pulumi.get(self, "connector_definition_version_arn")

    @property
    @pulumi.getter(name="coreDefinitionVersionArn")
    def core_definition_version_arn(self) -> Optional[str]:
        return pulumi.get(self, "core_definition_version_arn")

    @property
    @pulumi.getter(name="deviceDefinitionVersionArn")
    def device_definition_version_arn(self) -> Optional[str]:
        return pulumi.get(self, "device_definition_version_arn")

    @property
    @pulumi.getter(name="functionDefinitionVersionArn")
    def function_definition_version_arn(self) -> Optional[str]:
        return pulumi.get(self, "function_definition_version_arn")

    @property
    @pulumi.getter(name="loggerDefinitionVersionArn")
    def logger_definition_version_arn(self) -> Optional[str]:
        return pulumi.get(self, "logger_definition_version_arn")

    @property
    @pulumi.getter(name="resourceDefinitionVersionArn")
    def resource_definition_version_arn(self) -> Optional[str]:
        return pulumi.get(self, "resource_definition_version_arn")

    @property
    @pulumi.getter(name="subscriptionDefinitionVersionArn")
    def subscription_definition_version_arn(self) -> Optional[str]:
        return pulumi.get(self, "subscription_definition_version_arn")


@pulumi.output_type
class LoggerDefinitionLogger(dict):
    def __init__(__self__, *,
                 component: str,
                 id: str,
                 level: str,
                 type: str,
                 space: Optional[int] = None):
        pulumi.set(__self__, "component", component)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "level", level)
        pulumi.set(__self__, "type", type)
        if space is not None:
            pulumi.set(__self__, "space", space)

    @property
    @pulumi.getter
    def component(self) -> str:
        return pulumi.get(self, "component")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def level(self) -> str:
        return pulumi.get(self, "level")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def space(self) -> Optional[int]:
        return pulumi.get(self, "space")


@pulumi.output_type
class LoggerDefinitionLoggerDefinitionVersion(dict):
    def __init__(__self__, *,
                 loggers: Sequence['outputs.LoggerDefinitionLogger']):
        pulumi.set(__self__, "loggers", loggers)

    @property
    @pulumi.getter
    def loggers(self) -> Sequence['outputs.LoggerDefinitionLogger']:
        return pulumi.get(self, "loggers")


@pulumi.output_type
class LoggerDefinitionVersionLogger(dict):
    def __init__(__self__, *,
                 component: str,
                 id: str,
                 level: str,
                 type: str,
                 space: Optional[int] = None):
        pulumi.set(__self__, "component", component)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "level", level)
        pulumi.set(__self__, "type", type)
        if space is not None:
            pulumi.set(__self__, "space", space)

    @property
    @pulumi.getter
    def component(self) -> str:
        return pulumi.get(self, "component")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def level(self) -> str:
        return pulumi.get(self, "level")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def space(self) -> Optional[int]:
        return pulumi.get(self, "space")


@pulumi.output_type
class ResourceDefinitionGroupOwnerSetting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "autoAddGroupOwner":
            suggest = "auto_add_group_owner"
        elif key == "groupOwner":
            suggest = "group_owner"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionGroupOwnerSetting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionGroupOwnerSetting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionGroupOwnerSetting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 auto_add_group_owner: bool,
                 group_owner: Optional[str] = None):
        pulumi.set(__self__, "auto_add_group_owner", auto_add_group_owner)
        if group_owner is not None:
            pulumi.set(__self__, "group_owner", group_owner)

    @property
    @pulumi.getter(name="autoAddGroupOwner")
    def auto_add_group_owner(self) -> bool:
        return pulumi.get(self, "auto_add_group_owner")

    @property
    @pulumi.getter(name="groupOwner")
    def group_owner(self) -> Optional[str]:
        return pulumi.get(self, "group_owner")


@pulumi.output_type
class ResourceDefinitionLocalDeviceResourceData(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "sourcePath":
            suggest = "source_path"
        elif key == "groupOwnerSetting":
            suggest = "group_owner_setting"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionLocalDeviceResourceData. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionLocalDeviceResourceData.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionLocalDeviceResourceData.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 source_path: str,
                 group_owner_setting: Optional['outputs.ResourceDefinitionGroupOwnerSetting'] = None):
        pulumi.set(__self__, "source_path", source_path)
        if group_owner_setting is not None:
            pulumi.set(__self__, "group_owner_setting", group_owner_setting)

    @property
    @pulumi.getter(name="sourcePath")
    def source_path(self) -> str:
        return pulumi.get(self, "source_path")

    @property
    @pulumi.getter(name="groupOwnerSetting")
    def group_owner_setting(self) -> Optional['outputs.ResourceDefinitionGroupOwnerSetting']:
        return pulumi.get(self, "group_owner_setting")


@pulumi.output_type
class ResourceDefinitionLocalVolumeResourceData(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "destinationPath":
            suggest = "destination_path"
        elif key == "sourcePath":
            suggest = "source_path"
        elif key == "groupOwnerSetting":
            suggest = "group_owner_setting"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionLocalVolumeResourceData. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionLocalVolumeResourceData.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionLocalVolumeResourceData.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 destination_path: str,
                 source_path: str,
                 group_owner_setting: Optional['outputs.ResourceDefinitionGroupOwnerSetting'] = None):
        pulumi.set(__self__, "destination_path", destination_path)
        pulumi.set(__self__, "source_path", source_path)
        if group_owner_setting is not None:
            pulumi.set(__self__, "group_owner_setting", group_owner_setting)

    @property
    @pulumi.getter(name="destinationPath")
    def destination_path(self) -> str:
        return pulumi.get(self, "destination_path")

    @property
    @pulumi.getter(name="sourcePath")
    def source_path(self) -> str:
        return pulumi.get(self, "source_path")

    @property
    @pulumi.getter(name="groupOwnerSetting")
    def group_owner_setting(self) -> Optional['outputs.ResourceDefinitionGroupOwnerSetting']:
        return pulumi.get(self, "group_owner_setting")


@pulumi.output_type
class ResourceDefinitionResourceDataContainer(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "localDeviceResourceData":
            suggest = "local_device_resource_data"
        elif key == "localVolumeResourceData":
            suggest = "local_volume_resource_data"
        elif key == "s3MachineLearningModelResourceData":
            suggest = "s3_machine_learning_model_resource_data"
        elif key == "sageMakerMachineLearningModelResourceData":
            suggest = "sage_maker_machine_learning_model_resource_data"
        elif key == "secretsManagerSecretResourceData":
            suggest = "secrets_manager_secret_resource_data"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionResourceDataContainer. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionResourceDataContainer.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionResourceDataContainer.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 local_device_resource_data: Optional['outputs.ResourceDefinitionLocalDeviceResourceData'] = None,
                 local_volume_resource_data: Optional['outputs.ResourceDefinitionLocalVolumeResourceData'] = None,
                 s3_machine_learning_model_resource_data: Optional['outputs.ResourceDefinitionS3MachineLearningModelResourceData'] = None,
                 sage_maker_machine_learning_model_resource_data: Optional['outputs.ResourceDefinitionSageMakerMachineLearningModelResourceData'] = None,
                 secrets_manager_secret_resource_data: Optional['outputs.ResourceDefinitionSecretsManagerSecretResourceData'] = None):
        if local_device_resource_data is not None:
            pulumi.set(__self__, "local_device_resource_data", local_device_resource_data)
        if local_volume_resource_data is not None:
            pulumi.set(__self__, "local_volume_resource_data", local_volume_resource_data)
        if s3_machine_learning_model_resource_data is not None:
            pulumi.set(__self__, "s3_machine_learning_model_resource_data", s3_machine_learning_model_resource_data)
        if sage_maker_machine_learning_model_resource_data is not None:
            pulumi.set(__self__, "sage_maker_machine_learning_model_resource_data", sage_maker_machine_learning_model_resource_data)
        if secrets_manager_secret_resource_data is not None:
            pulumi.set(__self__, "secrets_manager_secret_resource_data", secrets_manager_secret_resource_data)

    @property
    @pulumi.getter(name="localDeviceResourceData")
    def local_device_resource_data(self) -> Optional['outputs.ResourceDefinitionLocalDeviceResourceData']:
        return pulumi.get(self, "local_device_resource_data")

    @property
    @pulumi.getter(name="localVolumeResourceData")
    def local_volume_resource_data(self) -> Optional['outputs.ResourceDefinitionLocalVolumeResourceData']:
        return pulumi.get(self, "local_volume_resource_data")

    @property
    @pulumi.getter(name="s3MachineLearningModelResourceData")
    def s3_machine_learning_model_resource_data(self) -> Optional['outputs.ResourceDefinitionS3MachineLearningModelResourceData']:
        return pulumi.get(self, "s3_machine_learning_model_resource_data")

    @property
    @pulumi.getter(name="sageMakerMachineLearningModelResourceData")
    def sage_maker_machine_learning_model_resource_data(self) -> Optional['outputs.ResourceDefinitionSageMakerMachineLearningModelResourceData']:
        return pulumi.get(self, "sage_maker_machine_learning_model_resource_data")

    @property
    @pulumi.getter(name="secretsManagerSecretResourceData")
    def secrets_manager_secret_resource_data(self) -> Optional['outputs.ResourceDefinitionSecretsManagerSecretResourceData']:
        return pulumi.get(self, "secrets_manager_secret_resource_data")


@pulumi.output_type
class ResourceDefinitionResourceDefinitionVersion(dict):
    def __init__(__self__, *,
                 resources: Sequence['outputs.ResourceDefinitionResourceInstance']):
        pulumi.set(__self__, "resources", resources)

    @property
    @pulumi.getter
    def resources(self) -> Sequence['outputs.ResourceDefinitionResourceInstance']:
        return pulumi.get(self, "resources")


@pulumi.output_type
class ResourceDefinitionResourceDownloadOwnerSetting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "groupOwner":
            suggest = "group_owner"
        elif key == "groupPermission":
            suggest = "group_permission"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionResourceDownloadOwnerSetting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionResourceDownloadOwnerSetting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionResourceDownloadOwnerSetting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 group_owner: str,
                 group_permission: str):
        pulumi.set(__self__, "group_owner", group_owner)
        pulumi.set(__self__, "group_permission", group_permission)

    @property
    @pulumi.getter(name="groupOwner")
    def group_owner(self) -> str:
        return pulumi.get(self, "group_owner")

    @property
    @pulumi.getter(name="groupPermission")
    def group_permission(self) -> str:
        return pulumi.get(self, "group_permission")


@pulumi.output_type
class ResourceDefinitionResourceInstance(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "resourceDataContainer":
            suggest = "resource_data_container"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionResourceInstance. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionResourceInstance.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionResourceInstance.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 id: str,
                 name: str,
                 resource_data_container: 'outputs.ResourceDefinitionResourceDataContainer'):
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "resource_data_container", resource_data_container)

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceDataContainer")
    def resource_data_container(self) -> 'outputs.ResourceDefinitionResourceDataContainer':
        return pulumi.get(self, "resource_data_container")


@pulumi.output_type
class ResourceDefinitionS3MachineLearningModelResourceData(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "destinationPath":
            suggest = "destination_path"
        elif key == "s3Uri":
            suggest = "s3_uri"
        elif key == "ownerSetting":
            suggest = "owner_setting"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionS3MachineLearningModelResourceData. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionS3MachineLearningModelResourceData.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionS3MachineLearningModelResourceData.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 destination_path: str,
                 s3_uri: str,
                 owner_setting: Optional['outputs.ResourceDefinitionResourceDownloadOwnerSetting'] = None):
        pulumi.set(__self__, "destination_path", destination_path)
        pulumi.set(__self__, "s3_uri", s3_uri)
        if owner_setting is not None:
            pulumi.set(__self__, "owner_setting", owner_setting)

    @property
    @pulumi.getter(name="destinationPath")
    def destination_path(self) -> str:
        return pulumi.get(self, "destination_path")

    @property
    @pulumi.getter(name="s3Uri")
    def s3_uri(self) -> str:
        return pulumi.get(self, "s3_uri")

    @property
    @pulumi.getter(name="ownerSetting")
    def owner_setting(self) -> Optional['outputs.ResourceDefinitionResourceDownloadOwnerSetting']:
        return pulumi.get(self, "owner_setting")


@pulumi.output_type
class ResourceDefinitionSageMakerMachineLearningModelResourceData(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "destinationPath":
            suggest = "destination_path"
        elif key == "sageMakerJobArn":
            suggest = "sage_maker_job_arn"
        elif key == "ownerSetting":
            suggest = "owner_setting"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionSageMakerMachineLearningModelResourceData. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionSageMakerMachineLearningModelResourceData.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionSageMakerMachineLearningModelResourceData.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 destination_path: str,
                 sage_maker_job_arn: str,
                 owner_setting: Optional['outputs.ResourceDefinitionResourceDownloadOwnerSetting'] = None):
        pulumi.set(__self__, "destination_path", destination_path)
        pulumi.set(__self__, "sage_maker_job_arn", sage_maker_job_arn)
        if owner_setting is not None:
            pulumi.set(__self__, "owner_setting", owner_setting)

    @property
    @pulumi.getter(name="destinationPath")
    def destination_path(self) -> str:
        return pulumi.get(self, "destination_path")

    @property
    @pulumi.getter(name="sageMakerJobArn")
    def sage_maker_job_arn(self) -> str:
        return pulumi.get(self, "sage_maker_job_arn")

    @property
    @pulumi.getter(name="ownerSetting")
    def owner_setting(self) -> Optional['outputs.ResourceDefinitionResourceDownloadOwnerSetting']:
        return pulumi.get(self, "owner_setting")


@pulumi.output_type
class ResourceDefinitionSecretsManagerSecretResourceData(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "aRN":
            suggest = "a_rn"
        elif key == "additionalStagingLabelsToDownload":
            suggest = "additional_staging_labels_to_download"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionSecretsManagerSecretResourceData. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionSecretsManagerSecretResourceData.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionSecretsManagerSecretResourceData.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 a_rn: str,
                 additional_staging_labels_to_download: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "a_rn", a_rn)
        if additional_staging_labels_to_download is not None:
            pulumi.set(__self__, "additional_staging_labels_to_download", additional_staging_labels_to_download)

    @property
    @pulumi.getter(name="aRN")
    def a_rn(self) -> str:
        return pulumi.get(self, "a_rn")

    @property
    @pulumi.getter(name="additionalStagingLabelsToDownload")
    def additional_staging_labels_to_download(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "additional_staging_labels_to_download")


@pulumi.output_type
class ResourceDefinitionVersionGroupOwnerSetting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "autoAddGroupOwner":
            suggest = "auto_add_group_owner"
        elif key == "groupOwner":
            suggest = "group_owner"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionVersionGroupOwnerSetting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionVersionGroupOwnerSetting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionVersionGroupOwnerSetting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 auto_add_group_owner: bool,
                 group_owner: Optional[str] = None):
        pulumi.set(__self__, "auto_add_group_owner", auto_add_group_owner)
        if group_owner is not None:
            pulumi.set(__self__, "group_owner", group_owner)

    @property
    @pulumi.getter(name="autoAddGroupOwner")
    def auto_add_group_owner(self) -> bool:
        return pulumi.get(self, "auto_add_group_owner")

    @property
    @pulumi.getter(name="groupOwner")
    def group_owner(self) -> Optional[str]:
        return pulumi.get(self, "group_owner")


@pulumi.output_type
class ResourceDefinitionVersionLocalDeviceResourceData(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "sourcePath":
            suggest = "source_path"
        elif key == "groupOwnerSetting":
            suggest = "group_owner_setting"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionVersionLocalDeviceResourceData. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionVersionLocalDeviceResourceData.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionVersionLocalDeviceResourceData.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 source_path: str,
                 group_owner_setting: Optional['outputs.ResourceDefinitionVersionGroupOwnerSetting'] = None):
        pulumi.set(__self__, "source_path", source_path)
        if group_owner_setting is not None:
            pulumi.set(__self__, "group_owner_setting", group_owner_setting)

    @property
    @pulumi.getter(name="sourcePath")
    def source_path(self) -> str:
        return pulumi.get(self, "source_path")

    @property
    @pulumi.getter(name="groupOwnerSetting")
    def group_owner_setting(self) -> Optional['outputs.ResourceDefinitionVersionGroupOwnerSetting']:
        return pulumi.get(self, "group_owner_setting")


@pulumi.output_type
class ResourceDefinitionVersionLocalVolumeResourceData(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "destinationPath":
            suggest = "destination_path"
        elif key == "sourcePath":
            suggest = "source_path"
        elif key == "groupOwnerSetting":
            suggest = "group_owner_setting"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionVersionLocalVolumeResourceData. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionVersionLocalVolumeResourceData.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionVersionLocalVolumeResourceData.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 destination_path: str,
                 source_path: str,
                 group_owner_setting: Optional['outputs.ResourceDefinitionVersionGroupOwnerSetting'] = None):
        pulumi.set(__self__, "destination_path", destination_path)
        pulumi.set(__self__, "source_path", source_path)
        if group_owner_setting is not None:
            pulumi.set(__self__, "group_owner_setting", group_owner_setting)

    @property
    @pulumi.getter(name="destinationPath")
    def destination_path(self) -> str:
        return pulumi.get(self, "destination_path")

    @property
    @pulumi.getter(name="sourcePath")
    def source_path(self) -> str:
        return pulumi.get(self, "source_path")

    @property
    @pulumi.getter(name="groupOwnerSetting")
    def group_owner_setting(self) -> Optional['outputs.ResourceDefinitionVersionGroupOwnerSetting']:
        return pulumi.get(self, "group_owner_setting")


@pulumi.output_type
class ResourceDefinitionVersionResourceDataContainer(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "localDeviceResourceData":
            suggest = "local_device_resource_data"
        elif key == "localVolumeResourceData":
            suggest = "local_volume_resource_data"
        elif key == "s3MachineLearningModelResourceData":
            suggest = "s3_machine_learning_model_resource_data"
        elif key == "sageMakerMachineLearningModelResourceData":
            suggest = "sage_maker_machine_learning_model_resource_data"
        elif key == "secretsManagerSecretResourceData":
            suggest = "secrets_manager_secret_resource_data"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionVersionResourceDataContainer. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionVersionResourceDataContainer.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionVersionResourceDataContainer.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 local_device_resource_data: Optional['outputs.ResourceDefinitionVersionLocalDeviceResourceData'] = None,
                 local_volume_resource_data: Optional['outputs.ResourceDefinitionVersionLocalVolumeResourceData'] = None,
                 s3_machine_learning_model_resource_data: Optional['outputs.ResourceDefinitionVersionS3MachineLearningModelResourceData'] = None,
                 sage_maker_machine_learning_model_resource_data: Optional['outputs.ResourceDefinitionVersionSageMakerMachineLearningModelResourceData'] = None,
                 secrets_manager_secret_resource_data: Optional['outputs.ResourceDefinitionVersionSecretsManagerSecretResourceData'] = None):
        if local_device_resource_data is not None:
            pulumi.set(__self__, "local_device_resource_data", local_device_resource_data)
        if local_volume_resource_data is not None:
            pulumi.set(__self__, "local_volume_resource_data", local_volume_resource_data)
        if s3_machine_learning_model_resource_data is not None:
            pulumi.set(__self__, "s3_machine_learning_model_resource_data", s3_machine_learning_model_resource_data)
        if sage_maker_machine_learning_model_resource_data is not None:
            pulumi.set(__self__, "sage_maker_machine_learning_model_resource_data", sage_maker_machine_learning_model_resource_data)
        if secrets_manager_secret_resource_data is not None:
            pulumi.set(__self__, "secrets_manager_secret_resource_data", secrets_manager_secret_resource_data)

    @property
    @pulumi.getter(name="localDeviceResourceData")
    def local_device_resource_data(self) -> Optional['outputs.ResourceDefinitionVersionLocalDeviceResourceData']:
        return pulumi.get(self, "local_device_resource_data")

    @property
    @pulumi.getter(name="localVolumeResourceData")
    def local_volume_resource_data(self) -> Optional['outputs.ResourceDefinitionVersionLocalVolumeResourceData']:
        return pulumi.get(self, "local_volume_resource_data")

    @property
    @pulumi.getter(name="s3MachineLearningModelResourceData")
    def s3_machine_learning_model_resource_data(self) -> Optional['outputs.ResourceDefinitionVersionS3MachineLearningModelResourceData']:
        return pulumi.get(self, "s3_machine_learning_model_resource_data")

    @property
    @pulumi.getter(name="sageMakerMachineLearningModelResourceData")
    def sage_maker_machine_learning_model_resource_data(self) -> Optional['outputs.ResourceDefinitionVersionSageMakerMachineLearningModelResourceData']:
        return pulumi.get(self, "sage_maker_machine_learning_model_resource_data")

    @property
    @pulumi.getter(name="secretsManagerSecretResourceData")
    def secrets_manager_secret_resource_data(self) -> Optional['outputs.ResourceDefinitionVersionSecretsManagerSecretResourceData']:
        return pulumi.get(self, "secrets_manager_secret_resource_data")


@pulumi.output_type
class ResourceDefinitionVersionResourceDownloadOwnerSetting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "groupOwner":
            suggest = "group_owner"
        elif key == "groupPermission":
            suggest = "group_permission"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionVersionResourceDownloadOwnerSetting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionVersionResourceDownloadOwnerSetting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionVersionResourceDownloadOwnerSetting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 group_owner: str,
                 group_permission: str):
        pulumi.set(__self__, "group_owner", group_owner)
        pulumi.set(__self__, "group_permission", group_permission)

    @property
    @pulumi.getter(name="groupOwner")
    def group_owner(self) -> str:
        return pulumi.get(self, "group_owner")

    @property
    @pulumi.getter(name="groupPermission")
    def group_permission(self) -> str:
        return pulumi.get(self, "group_permission")


@pulumi.output_type
class ResourceDefinitionVersionResourceInstance(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "resourceDataContainer":
            suggest = "resource_data_container"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionVersionResourceInstance. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionVersionResourceInstance.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionVersionResourceInstance.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 id: str,
                 name: str,
                 resource_data_container: 'outputs.ResourceDefinitionVersionResourceDataContainer'):
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "resource_data_container", resource_data_container)

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceDataContainer")
    def resource_data_container(self) -> 'outputs.ResourceDefinitionVersionResourceDataContainer':
        return pulumi.get(self, "resource_data_container")


@pulumi.output_type
class ResourceDefinitionVersionS3MachineLearningModelResourceData(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "destinationPath":
            suggest = "destination_path"
        elif key == "s3Uri":
            suggest = "s3_uri"
        elif key == "ownerSetting":
            suggest = "owner_setting"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionVersionS3MachineLearningModelResourceData. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionVersionS3MachineLearningModelResourceData.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionVersionS3MachineLearningModelResourceData.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 destination_path: str,
                 s3_uri: str,
                 owner_setting: Optional['outputs.ResourceDefinitionVersionResourceDownloadOwnerSetting'] = None):
        pulumi.set(__self__, "destination_path", destination_path)
        pulumi.set(__self__, "s3_uri", s3_uri)
        if owner_setting is not None:
            pulumi.set(__self__, "owner_setting", owner_setting)

    @property
    @pulumi.getter(name="destinationPath")
    def destination_path(self) -> str:
        return pulumi.get(self, "destination_path")

    @property
    @pulumi.getter(name="s3Uri")
    def s3_uri(self) -> str:
        return pulumi.get(self, "s3_uri")

    @property
    @pulumi.getter(name="ownerSetting")
    def owner_setting(self) -> Optional['outputs.ResourceDefinitionVersionResourceDownloadOwnerSetting']:
        return pulumi.get(self, "owner_setting")


@pulumi.output_type
class ResourceDefinitionVersionSageMakerMachineLearningModelResourceData(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "destinationPath":
            suggest = "destination_path"
        elif key == "sageMakerJobArn":
            suggest = "sage_maker_job_arn"
        elif key == "ownerSetting":
            suggest = "owner_setting"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionVersionSageMakerMachineLearningModelResourceData. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionVersionSageMakerMachineLearningModelResourceData.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionVersionSageMakerMachineLearningModelResourceData.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 destination_path: str,
                 sage_maker_job_arn: str,
                 owner_setting: Optional['outputs.ResourceDefinitionVersionResourceDownloadOwnerSetting'] = None):
        pulumi.set(__self__, "destination_path", destination_path)
        pulumi.set(__self__, "sage_maker_job_arn", sage_maker_job_arn)
        if owner_setting is not None:
            pulumi.set(__self__, "owner_setting", owner_setting)

    @property
    @pulumi.getter(name="destinationPath")
    def destination_path(self) -> str:
        return pulumi.get(self, "destination_path")

    @property
    @pulumi.getter(name="sageMakerJobArn")
    def sage_maker_job_arn(self) -> str:
        return pulumi.get(self, "sage_maker_job_arn")

    @property
    @pulumi.getter(name="ownerSetting")
    def owner_setting(self) -> Optional['outputs.ResourceDefinitionVersionResourceDownloadOwnerSetting']:
        return pulumi.get(self, "owner_setting")


@pulumi.output_type
class ResourceDefinitionVersionSecretsManagerSecretResourceData(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "aRN":
            suggest = "a_rn"
        elif key == "additionalStagingLabelsToDownload":
            suggest = "additional_staging_labels_to_download"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ResourceDefinitionVersionSecretsManagerSecretResourceData. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ResourceDefinitionVersionSecretsManagerSecretResourceData.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ResourceDefinitionVersionSecretsManagerSecretResourceData.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 a_rn: str,
                 additional_staging_labels_to_download: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "a_rn", a_rn)
        if additional_staging_labels_to_download is not None:
            pulumi.set(__self__, "additional_staging_labels_to_download", additional_staging_labels_to_download)

    @property
    @pulumi.getter(name="aRN")
    def a_rn(self) -> str:
        return pulumi.get(self, "a_rn")

    @property
    @pulumi.getter(name="additionalStagingLabelsToDownload")
    def additional_staging_labels_to_download(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "additional_staging_labels_to_download")


@pulumi.output_type
class SubscriptionDefinitionSubscription(dict):
    def __init__(__self__, *,
                 id: str,
                 source: str,
                 subject: str,
                 target: str):
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "source", source)
        pulumi.set(__self__, "subject", subject)
        pulumi.set(__self__, "target", target)

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def source(self) -> str:
        return pulumi.get(self, "source")

    @property
    @pulumi.getter
    def subject(self) -> str:
        return pulumi.get(self, "subject")

    @property
    @pulumi.getter
    def target(self) -> str:
        return pulumi.get(self, "target")


@pulumi.output_type
class SubscriptionDefinitionSubscriptionDefinitionVersion(dict):
    def __init__(__self__, *,
                 subscriptions: Sequence['outputs.SubscriptionDefinitionSubscription']):
        pulumi.set(__self__, "subscriptions", subscriptions)

    @property
    @pulumi.getter
    def subscriptions(self) -> Sequence['outputs.SubscriptionDefinitionSubscription']:
        return pulumi.get(self, "subscriptions")


@pulumi.output_type
class SubscriptionDefinitionVersionSubscription(dict):
    def __init__(__self__, *,
                 id: str,
                 source: str,
                 subject: str,
                 target: str):
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "source", source)
        pulumi.set(__self__, "subject", subject)
        pulumi.set(__self__, "target", target)

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def source(self) -> str:
        return pulumi.get(self, "source")

    @property
    @pulumi.getter
    def subject(self) -> str:
        return pulumi.get(self, "subject")

    @property
    @pulumi.getter
    def target(self) -> str:
        return pulumi.get(self, "target")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DBInstanceArgs', 'DBInstance']

@pulumi.input_type
class DBInstanceArgs:
    def __init__(__self__, *,
                 d_b_instance_class: pulumi.Input[str],
                 allocated_storage: Optional[pulumi.Input[str]] = None,
                 allow_major_version_upgrade: Optional[pulumi.Input[bool]] = None,
                 associated_roles: Optional[pulumi.Input[Sequence[pulumi.Input['DBInstanceDBInstanceRoleArgs']]]] = None,
                 auto_minor_version_upgrade: Optional[pulumi.Input[bool]] = None,
                 availability_zone: Optional[pulumi.Input[str]] = None,
                 backup_retention_period: Optional[pulumi.Input[int]] = None,
                 c_a_certificate_identifier: Optional[pulumi.Input[str]] = None,
                 character_set_name: Optional[pulumi.Input[str]] = None,
                 copy_tags_to_snapshot: Optional[pulumi.Input[bool]] = None,
                 d_b_cluster_identifier: Optional[pulumi.Input[str]] = None,
                 d_b_instance_identifier: Optional[pulumi.Input[str]] = None,
                 d_b_name: Optional[pulumi.Input[str]] = None,
                 d_b_parameter_group_name: Optional[pulumi.Input[str]] = None,
                 d_b_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 d_b_snapshot_identifier: Optional[pulumi.Input[str]] = None,
                 d_b_subnet_group_name: Optional[pulumi.Input[str]] = None,
                 delete_automated_backups: Optional[pulumi.Input[bool]] = None,
                 deletion_protection: Optional[pulumi.Input[bool]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 domain_iam_role_name: Optional[pulumi.Input[str]] = None,
                 enable_cloudwatch_logs_exports: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 enable_iam_database_authentication: Optional[pulumi.Input[bool]] = None,
                 enable_performance_insights: Optional[pulumi.Input[bool]] = None,
                 endpoint_address: Optional[pulumi.Input[str]] = None,
                 endpoint_port: Optional[pulumi.Input[str]] = None,
                 engine: Optional[pulumi.Input[str]] = None,
                 engine_version: Optional[pulumi.Input[str]] = None,
                 iops: Optional[pulumi.Input[int]] = None,
                 kms_key_id: Optional[pulumi.Input[str]] = None,
                 license_model: Optional[pulumi.Input[str]] = None,
                 master_user_password: Optional[pulumi.Input[str]] = None,
                 master_username: Optional[pulumi.Input[str]] = None,
                 max_allocated_storage: Optional[pulumi.Input[int]] = None,
                 monitoring_interval: Optional[pulumi.Input[int]] = None,
                 monitoring_role_arn: Optional[pulumi.Input[str]] = None,
                 multi_az: Optional[pulumi.Input[bool]] = None,
                 option_group_name: Optional[pulumi.Input[str]] = None,
                 performance_insights_kms_key_id: Optional[pulumi.Input[str]] = None,
                 performance_insights_retention_period: Optional[pulumi.Input[int]] = None,
                 port: Optional[pulumi.Input[str]] = None,
                 preferred_backup_window: Optional[pulumi.Input[str]] = None,
                 preferred_maintenance_window: Optional[pulumi.Input[str]] = None,
                 processor_features: Optional[pulumi.Input[Sequence[pulumi.Input['DBInstanceProcessorFeatureArgs']]]] = None,
                 promotion_tier: Optional[pulumi.Input[int]] = None,
                 publicly_accessible: Optional[pulumi.Input[bool]] = None,
                 source_db_instance_identifier: Optional[pulumi.Input[str]] = None,
                 source_region: Optional[pulumi.Input[str]] = None,
                 storage_encrypted: Optional[pulumi.Input[bool]] = None,
                 storage_type: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['DBInstanceTagArgs']]]] = None,
                 timezone: Optional[pulumi.Input[str]] = None,
                 use_default_processor_features: Optional[pulumi.Input[bool]] = None,
                 v_pc_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a DBInstance resource.
        """
        pulumi.set(__self__, "d_b_instance_class", d_b_instance_class)
        if allocated_storage is not None:
            pulumi.set(__self__, "allocated_storage", allocated_storage)
        if allow_major_version_upgrade is not None:
            pulumi.set(__self__, "allow_major_version_upgrade", allow_major_version_upgrade)
        if associated_roles is not None:
            pulumi.set(__self__, "associated_roles", associated_roles)
        if auto_minor_version_upgrade is not None:
            pulumi.set(__self__, "auto_minor_version_upgrade", auto_minor_version_upgrade)
        if availability_zone is not None:
            pulumi.set(__self__, "availability_zone", availability_zone)
        if backup_retention_period is not None:
            pulumi.set(__self__, "backup_retention_period", backup_retention_period)
        if c_a_certificate_identifier is not None:
            pulumi.set(__self__, "c_a_certificate_identifier", c_a_certificate_identifier)
        if character_set_name is not None:
            pulumi.set(__self__, "character_set_name", character_set_name)
        if copy_tags_to_snapshot is not None:
            pulumi.set(__self__, "copy_tags_to_snapshot", copy_tags_to_snapshot)
        if d_b_cluster_identifier is not None:
            pulumi.set(__self__, "d_b_cluster_identifier", d_b_cluster_identifier)
        if d_b_instance_identifier is not None:
            pulumi.set(__self__, "d_b_instance_identifier", d_b_instance_identifier)
        if d_b_name is not None:
            pulumi.set(__self__, "d_b_name", d_b_name)
        if d_b_parameter_group_name is not None:
            pulumi.set(__self__, "d_b_parameter_group_name", d_b_parameter_group_name)
        if d_b_security_groups is not None:
            pulumi.set(__self__, "d_b_security_groups", d_b_security_groups)
        if d_b_snapshot_identifier is not None:
            pulumi.set(__self__, "d_b_snapshot_identifier", d_b_snapshot_identifier)
        if d_b_subnet_group_name is not None:
            pulumi.set(__self__, "d_b_subnet_group_name", d_b_subnet_group_name)
        if delete_automated_backups is not None:
            pulumi.set(__self__, "delete_automated_backups", delete_automated_backups)
        if deletion_protection is not None:
            pulumi.set(__self__, "deletion_protection", deletion_protection)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if domain_iam_role_name is not None:
            pulumi.set(__self__, "domain_iam_role_name", domain_iam_role_name)
        if enable_cloudwatch_logs_exports is not None:
            pulumi.set(__self__, "enable_cloudwatch_logs_exports", enable_cloudwatch_logs_exports)
        if enable_iam_database_authentication is not None:
            pulumi.set(__self__, "enable_iam_database_authentication", enable_iam_database_authentication)
        if enable_performance_insights is not None:
            pulumi.set(__self__, "enable_performance_insights", enable_performance_insights)
        if endpoint_address is not None:
            pulumi.set(__self__, "endpoint_address", endpoint_address)
        if endpoint_port is not None:
            pulumi.set(__self__, "endpoint_port", endpoint_port)
        if engine is not None:
            pulumi.set(__self__, "engine", engine)
        if engine_version is not None:
            pulumi.set(__self__, "engine_version", engine_version)
        if iops is not None:
            pulumi.set(__self__, "iops", iops)
        if kms_key_id is not None:
            pulumi.set(__self__, "kms_key_id", kms_key_id)
        if license_model is not None:
            pulumi.set(__self__, "license_model", license_model)
        if master_user_password is not None:
            pulumi.set(__self__, "master_user_password", master_user_password)
        if master_username is not None:
            pulumi.set(__self__, "master_username", master_username)
        if max_allocated_storage is not None:
            pulumi.set(__self__, "max_allocated_storage", max_allocated_storage)
        if monitoring_interval is not None:
            pulumi.set(__self__, "monitoring_interval", monitoring_interval)
        if monitoring_role_arn is not None:
            pulumi.set(__self__, "monitoring_role_arn", monitoring_role_arn)
        if multi_az is not None:
            pulumi.set(__self__, "multi_az", multi_az)
        if option_group_name is not None:
            pulumi.set(__self__, "option_group_name", option_group_name)
        if performance_insights_kms_key_id is not None:
            pulumi.set(__self__, "performance_insights_kms_key_id", performance_insights_kms_key_id)
        if performance_insights_retention_period is not None:
            pulumi.set(__self__, "performance_insights_retention_period", performance_insights_retention_period)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if preferred_backup_window is not None:
            pulumi.set(__self__, "preferred_backup_window", preferred_backup_window)
        if preferred_maintenance_window is not None:
            pulumi.set(__self__, "preferred_maintenance_window", preferred_maintenance_window)
        if processor_features is not None:
            pulumi.set(__self__, "processor_features", processor_features)
        if promotion_tier is not None:
            pulumi.set(__self__, "promotion_tier", promotion_tier)
        if publicly_accessible is not None:
            pulumi.set(__self__, "publicly_accessible", publicly_accessible)
        if source_db_instance_identifier is not None:
            pulumi.set(__self__, "source_db_instance_identifier", source_db_instance_identifier)
        if source_region is not None:
            pulumi.set(__self__, "source_region", source_region)
        if storage_encrypted is not None:
            pulumi.set(__self__, "storage_encrypted", storage_encrypted)
        if storage_type is not None:
            pulumi.set(__self__, "storage_type", storage_type)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if timezone is not None:
            pulumi.set(__self__, "timezone", timezone)
        if use_default_processor_features is not None:
            pulumi.set(__self__, "use_default_processor_features", use_default_processor_features)
        if v_pc_security_groups is not None:
            pulumi.set(__self__, "v_pc_security_groups", v_pc_security_groups)

    @property
    @pulumi.getter(name="dBInstanceClass")
    def d_b_instance_class(self) -> pulumi.Input[str]:
        return pulumi.get(self, "d_b_instance_class")

    @d_b_instance_class.setter
    def d_b_instance_class(self, value: pulumi.Input[str]):
        pulumi.set(self, "d_b_instance_class", value)

    @property
    @pulumi.getter(name="allocatedStorage")
    def allocated_storage(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "allocated_storage")

    @allocated_storage.setter
    def allocated_storage(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "allocated_storage", value)

    @property
    @pulumi.getter(name="allowMajorVersionUpgrade")
    def allow_major_version_upgrade(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "allow_major_version_upgrade")

    @allow_major_version_upgrade.setter
    def allow_major_version_upgrade(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allow_major_version_upgrade", value)

    @property
    @pulumi.getter(name="associatedRoles")
    def associated_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DBInstanceDBInstanceRoleArgs']]]]:
        return pulumi.get(self, "associated_roles")

    @associated_roles.setter
    def associated_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DBInstanceDBInstanceRoleArgs']]]]):
        pulumi.set(self, "associated_roles", value)

    @property
    @pulumi.getter(name="autoMinorVersionUpgrade")
    def auto_minor_version_upgrade(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "auto_minor_version_upgrade")

    @auto_minor_version_upgrade.setter
    def auto_minor_version_upgrade(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_minor_version_upgrade", value)

    @property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "availability_zone")

    @availability_zone.setter
    def availability_zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "availability_zone", value)

    @property
    @pulumi.getter(name="backupRetentionPeriod")
    def backup_retention_period(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "backup_retention_period")

    @backup_retention_period.setter
    def backup_retention_period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "backup_retention_period", value)

    @property
    @pulumi.getter(name="cACertificateIdentifier")
    def c_a_certificate_identifier(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "c_a_certificate_identifier")

    @c_a_certificate_identifier.setter
    def c_a_certificate_identifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "c_a_certificate_identifier", value)

    @property
    @pulumi.getter(name="characterSetName")
    def character_set_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "character_set_name")

    @character_set_name.setter
    def character_set_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "character_set_name", value)

    @property
    @pulumi.getter(name="copyTagsToSnapshot")
    def copy_tags_to_snapshot(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "copy_tags_to_snapshot")

    @copy_tags_to_snapshot.setter
    def copy_tags_to_snapshot(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "copy_tags_to_snapshot", value)

    @property
    @pulumi.getter(name="dBClusterIdentifier")
    def d_b_cluster_identifier(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "d_b_cluster_identifier")

    @d_b_cluster_identifier.setter
    def d_b_cluster_identifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "d_b_cluster_identifier", value)

    @property
    @pulumi.getter(name="dBInstanceIdentifier")
    def d_b_instance_identifier(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "d_b_instance_identifier")

    @d_b_instance_identifier.setter
    def d_b_instance_identifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "d_b_instance_identifier", value)

    @property
    @pulumi.getter(name="dBName")
    def d_b_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "d_b_name")

    @d_b_name.setter
    def d_b_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "d_b_name", value)

    @property
    @pulumi.getter(name="dBParameterGroupName")
    def d_b_parameter_group_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "d_b_parameter_group_name")

    @d_b_parameter_group_name.setter
    def d_b_parameter_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "d_b_parameter_group_name", value)

    @property
    @pulumi.getter(name="dBSecurityGroups")
    def d_b_security_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "d_b_security_groups")

    @d_b_security_groups.setter
    def d_b_security_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "d_b_security_groups", value)

    @property
    @pulumi.getter(name="dBSnapshotIdentifier")
    def d_b_snapshot_identifier(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "d_b_snapshot_identifier")

    @d_b_snapshot_identifier.setter
    def d_b_snapshot_identifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "d_b_snapshot_identifier", value)

    @property
    @pulumi.getter(name="dBSubnetGroupName")
    def d_b_subnet_group_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "d_b_subnet_group_name")

    @d_b_subnet_group_name.setter
    def d_b_subnet_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "d_b_subnet_group_name", value)

    @property
    @pulumi.getter(name="deleteAutomatedBackups")
    def delete_automated_backups(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "delete_automated_backups")

    @delete_automated_backups.setter
    def delete_automated_backups(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "delete_automated_backups", value)

    @property
    @pulumi.getter(name="deletionProtection")
    def deletion_protection(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "deletion_protection")

    @deletion_protection.setter
    def deletion_protection(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "deletion_protection", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="domainIAMRoleName")
    def domain_iam_role_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "domain_iam_role_name")

    @domain_iam_role_name.setter
    def domain_iam_role_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain_iam_role_name", value)

    @property
    @pulumi.getter(name="enableCloudwatchLogsExports")
    def enable_cloudwatch_logs_exports(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "enable_cloudwatch_logs_exports")

    @enable_cloudwatch_logs_exports.setter
    def enable_cloudwatch_logs_exports(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "enable_cloudwatch_logs_exports", value)

    @property
    @pulumi.getter(name="enableIAMDatabaseAuthentication")
    def enable_iam_database_authentication(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "enable_iam_database_authentication")

    @enable_iam_database_authentication.setter
    def enable_iam_database_authentication(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_iam_database_authentication", value)

    @property
    @pulumi.getter(name="enablePerformanceInsights")
    def enable_performance_insights(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "enable_performance_insights")

    @enable_performance_insights.setter
    def enable_performance_insights(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_performance_insights", value)

    @property
    @pulumi.getter(name="endpointAddress")
    def endpoint_address(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "endpoint_address")

    @endpoint_address.setter
    def endpoint_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint_address", value)

    @property
    @pulumi.getter(name="endpointPort")
    def endpoint_port(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "endpoint_port")

    @endpoint_port.setter
    def endpoint_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint_port", value)

    @property
    @pulumi.getter
    def engine(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "engine", value)

    @property
    @pulumi.getter(name="engineVersion")
    def engine_version(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "engine_version")

    @engine_version.setter
    def engine_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "engine_version", value)

    @property
    @pulumi.getter
    def iops(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "iops")

    @iops.setter
    def iops(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "iops", value)

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "kms_key_id")

    @kms_key_id.setter
    def kms_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kms_key_id", value)

    @property
    @pulumi.getter(name="licenseModel")
    def license_model(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "license_model")

    @license_model.setter
    def license_model(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "license_model", value)

    @property
    @pulumi.getter(name="masterUserPassword")
    def master_user_password(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "master_user_password")

    @master_user_password.setter
    def master_user_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "master_user_password", value)

    @property
    @pulumi.getter(name="masterUsername")
    def master_username(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "master_username")

    @master_username.setter
    def master_username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "master_username", value)

    @property
    @pulumi.getter(name="maxAllocatedStorage")
    def max_allocated_storage(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "max_allocated_storage")

    @max_allocated_storage.setter
    def max_allocated_storage(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_allocated_storage", value)

    @property
    @pulumi.getter(name="monitoringInterval")
    def monitoring_interval(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "monitoring_interval")

    @monitoring_interval.setter
    def monitoring_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "monitoring_interval", value)

    @property
    @pulumi.getter(name="monitoringRoleArn")
    def monitoring_role_arn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "monitoring_role_arn")

    @monitoring_role_arn.setter
    def monitoring_role_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "monitoring_role_arn", value)

    @property
    @pulumi.getter(name="multiAZ")
    def multi_az(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "multi_az")

    @multi_az.setter
    def multi_az(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "multi_az", value)

    @property
    @pulumi.getter(name="optionGroupName")
    def option_group_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "option_group_name")

    @option_group_name.setter
    def option_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "option_group_name", value)

    @property
    @pulumi.getter(name="performanceInsightsKMSKeyId")
    def performance_insights_kms_key_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "performance_insights_kms_key_id")

    @performance_insights_kms_key_id.setter
    def performance_insights_kms_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "performance_insights_kms_key_id", value)

    @property
    @pulumi.getter(name="performanceInsightsRetentionPeriod")
    def performance_insights_retention_period(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "performance_insights_retention_period")

    @performance_insights_retention_period.setter
    def performance_insights_retention_period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "performance_insights_retention_period", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="preferredBackupWindow")
    def preferred_backup_window(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "preferred_backup_window")

    @preferred_backup_window.setter
    def preferred_backup_window(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "preferred_backup_window", value)

    @property
    @pulumi.getter(name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "preferred_maintenance_window")

    @preferred_maintenance_window.setter
    def preferred_maintenance_window(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "preferred_maintenance_window", value)

    @property
    @pulumi.getter(name="processorFeatures")
    def processor_features(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DBInstanceProcessorFeatureArgs']]]]:
        return pulumi.get(self, "processor_features")

    @processor_features.setter
    def processor_features(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DBInstanceProcessorFeatureArgs']]]]):
        pulumi.set(self, "processor_features", value)

    @property
    @pulumi.getter(name="promotionTier")
    def promotion_tier(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "promotion_tier")

    @promotion_tier.setter
    def promotion_tier(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "promotion_tier", value)

    @property
    @pulumi.getter(name="publiclyAccessible")
    def publicly_accessible(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "publicly_accessible")

    @publicly_accessible.setter
    def publicly_accessible(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "publicly_accessible", value)

    @property
    @pulumi.getter(name="sourceDBInstanceIdentifier")
    def source_db_instance_identifier(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "source_db_instance_identifier")

    @source_db_instance_identifier.setter
    def source_db_instance_identifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_db_instance_identifier", value)

    @property
    @pulumi.getter(name="sourceRegion")
    def source_region(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "source_region")

    @source_region.setter
    def source_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_region", value)

    @property
    @pulumi.getter(name="storageEncrypted")
    def storage_encrypted(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "storage_encrypted")

    @storage_encrypted.setter
    def storage_encrypted(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "storage_encrypted", value)

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "storage_type")

    @storage_type.setter
    def storage_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "storage_type", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DBInstanceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DBInstanceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def timezone(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "timezone")

    @timezone.setter
    def timezone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "timezone", value)

    @property
    @pulumi.getter(name="useDefaultProcessorFeatures")
    def use_default_processor_features(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "use_default_processor_features")

    @use_default_processor_features.setter
    def use_default_processor_features(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_default_processor_features", value)

    @property
    @pulumi.getter(name="vPCSecurityGroups")
    def v_pc_security_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "v_pc_security_groups")

    @v_pc_security_groups.setter
    def v_pc_security_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "v_pc_security_groups", value)


warnings.warn("""DBInstance is not yet supported by AWS Native, so its creation will currently fail. Please use the classic AWS provider, if possible.""", DeprecationWarning)


class DBInstance(pulumi.CustomResource):
    warnings.warn("""DBInstance is not yet supported by AWS Native, so its creation will currently fail. Please use the classic AWS provider, if possible.""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allocated_storage: Optional[pulumi.Input[str]] = None,
                 allow_major_version_upgrade: Optional[pulumi.Input[bool]] = None,
                 associated_roles: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DBInstanceDBInstanceRoleArgs']]]]] = None,
                 auto_minor_version_upgrade: Optional[pulumi.Input[bool]] = None,
                 availability_zone: Optional[pulumi.Input[str]] = None,
                 backup_retention_period: Optional[pulumi.Input[int]] = None,
                 c_a_certificate_identifier: Optional[pulumi.Input[str]] = None,
                 character_set_name: Optional[pulumi.Input[str]] = None,
                 copy_tags_to_snapshot: Optional[pulumi.Input[bool]] = None,
                 d_b_cluster_identifier: Optional[pulumi.Input[str]] = None,
                 d_b_instance_class: Optional[pulumi.Input[str]] = None,
                 d_b_instance_identifier: Optional[pulumi.Input[str]] = None,
                 d_b_name: Optional[pulumi.Input[str]] = None,
                 d_b_parameter_group_name: Optional[pulumi.Input[str]] = None,
                 d_b_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 d_b_snapshot_identifier: Optional[pulumi.Input[str]] = None,
                 d_b_subnet_group_name: Optional[pulumi.Input[str]] = None,
                 delete_automated_backups: Optional[pulumi.Input[bool]] = None,
                 deletion_protection: Optional[pulumi.Input[bool]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 domain_iam_role_name: Optional[pulumi.Input[str]] = None,
                 enable_cloudwatch_logs_exports: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 enable_iam_database_authentication: Optional[pulumi.Input[bool]] = None,
                 enable_performance_insights: Optional[pulumi.Input[bool]] = None,
                 endpoint_address: Optional[pulumi.Input[str]] = None,
                 endpoint_port: Optional[pulumi.Input[str]] = None,
                 engine: Optional[pulumi.Input[str]] = None,
                 engine_version: Optional[pulumi.Input[str]] = None,
                 iops: Optional[pulumi.Input[int]] = None,
                 kms_key_id: Optional[pulumi.Input[str]] = None,
                 license_model: Optional[pulumi.Input[str]] = None,
                 master_user_password: Optional[pulumi.Input[str]] = None,
                 master_username: Optional[pulumi.Input[str]] = None,
                 max_allocated_storage: Optional[pulumi.Input[int]] = None,
                 monitoring_interval: Optional[pulumi.Input[int]] = None,
                 monitoring_role_arn: Optional[pulumi.Input[str]] = None,
                 multi_az: Optional[pulumi.Input[bool]] = None,
                 option_group_name: Optional[pulumi.Input[str]] = None,
                 performance_insights_kms_key_id: Optional[pulumi.Input[str]] = None,
                 performance_insights_retention_period: Optional[pulumi.Input[int]] = None,
                 port: Optional[pulumi.Input[str]] = None,
                 preferred_backup_window: Optional[pulumi.Input[str]] = None,
                 preferred_maintenance_window: Optional[pulumi.Input[str]] = None,
                 processor_features: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DBInstanceProcessorFeatureArgs']]]]] = None,
                 promotion_tier: Optional[pulumi.Input[int]] = None,
                 publicly_accessible: Optional[pulumi.Input[bool]] = None,
                 source_db_instance_identifier: Optional[pulumi.Input[str]] = None,
                 source_region: Optional[pulumi.Input[str]] = None,
                 storage_encrypted: Optional[pulumi.Input[bool]] = None,
                 storage_type: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DBInstanceTagArgs']]]]] = None,
                 timezone: Optional[pulumi.Input[str]] = None,
                 use_default_processor_features: Optional[pulumi.Input[bool]] = None,
                 v_pc_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Resource Type definition for AWS::RDS::DBInstance

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DBInstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource Type definition for AWS::RDS::DBInstance

        :param str resource_name: The name of the resource.
        :param DBInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DBInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allocated_storage: Optional[pulumi.Input[str]] = None,
                 allow_major_version_upgrade: Optional[pulumi.Input[bool]] = None,
                 associated_roles: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DBInstanceDBInstanceRoleArgs']]]]] = None,
                 auto_minor_version_upgrade: Optional[pulumi.Input[bool]] = None,
                 availability_zone: Optional[pulumi.Input[str]] = None,
                 backup_retention_period: Optional[pulumi.Input[int]] = None,
                 c_a_certificate_identifier: Optional[pulumi.Input[str]] = None,
                 character_set_name: Optional[pulumi.Input[str]] = None,
                 copy_tags_to_snapshot: Optional[pulumi.Input[bool]] = None,
                 d_b_cluster_identifier: Optional[pulumi.Input[str]] = None,
                 d_b_instance_class: Optional[pulumi.Input[str]] = None,
                 d_b_instance_identifier: Optional[pulumi.Input[str]] = None,
                 d_b_name: Optional[pulumi.Input[str]] = None,
                 d_b_parameter_group_name: Optional[pulumi.Input[str]] = None,
                 d_b_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 d_b_snapshot_identifier: Optional[pulumi.Input[str]] = None,
                 d_b_subnet_group_name: Optional[pulumi.Input[str]] = None,
                 delete_automated_backups: Optional[pulumi.Input[bool]] = None,
                 deletion_protection: Optional[pulumi.Input[bool]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 domain_iam_role_name: Optional[pulumi.Input[str]] = None,
                 enable_cloudwatch_logs_exports: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 enable_iam_database_authentication: Optional[pulumi.Input[bool]] = None,
                 enable_performance_insights: Optional[pulumi.Input[bool]] = None,
                 endpoint_address: Optional[pulumi.Input[str]] = None,
                 endpoint_port: Optional[pulumi.Input[str]] = None,
                 engine: Optional[pulumi.Input[str]] = None,
                 engine_version: Optional[pulumi.Input[str]] = None,
                 iops: Optional[pulumi.Input[int]] = None,
                 kms_key_id: Optional[pulumi.Input[str]] = None,
                 license_model: Optional[pulumi.Input[str]] = None,
                 master_user_password: Optional[pulumi.Input[str]] = None,
                 master_username: Optional[pulumi.Input[str]] = None,
                 max_allocated_storage: Optional[pulumi.Input[int]] = None,
                 monitoring_interval: Optional[pulumi.Input[int]] = None,
                 monitoring_role_arn: Optional[pulumi.Input[str]] = None,
                 multi_az: Optional[pulumi.Input[bool]] = None,
                 option_group_name: Optional[pulumi.Input[str]] = None,
                 performance_insights_kms_key_id: Optional[pulumi.Input[str]] = None,
                 performance_insights_retention_period: Optional[pulumi.Input[int]] = None,
                 port: Optional[pulumi.Input[str]] = None,
                 preferred_backup_window: Optional[pulumi.Input[str]] = None,
                 preferred_maintenance_window: Optional[pulumi.Input[str]] = None,
                 processor_features: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DBInstanceProcessorFeatureArgs']]]]] = None,
                 promotion_tier: Optional[pulumi.Input[int]] = None,
                 publicly_accessible: Optional[pulumi.Input[bool]] = None,
                 source_db_instance_identifier: Optional[pulumi.Input[str]] = None,
                 source_region: Optional[pulumi.Input[str]] = None,
                 storage_encrypted: Optional[pulumi.Input[bool]] = None,
                 storage_type: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DBInstanceTagArgs']]]]] = None,
                 timezone: Optional[pulumi.Input[str]] = None,
                 use_default_processor_features: Optional[pulumi.Input[bool]] = None,
                 v_pc_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        pulumi.log.warn("""DBInstance is deprecated: DBInstance is not yet supported by AWS Native, so its creation will currently fail. Please use the classic AWS provider, if possible.""")
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DBInstanceArgs.__new__(DBInstanceArgs)

            __props__.__dict__["allocated_storage"] = allocated_storage
            __props__.__dict__["allow_major_version_upgrade"] = allow_major_version_upgrade
            __props__.__dict__["associated_roles"] = associated_roles
            __props__.__dict__["auto_minor_version_upgrade"] = auto_minor_version_upgrade
            __props__.__dict__["availability_zone"] = availability_zone
            __props__.__dict__["backup_retention_period"] = backup_retention_period
            __props__.__dict__["c_a_certificate_identifier"] = c_a_certificate_identifier
            __props__.__dict__["character_set_name"] = character_set_name
            __props__.__dict__["copy_tags_to_snapshot"] = copy_tags_to_snapshot
            __props__.__dict__["d_b_cluster_identifier"] = d_b_cluster_identifier
            if d_b_instance_class is None and not opts.urn:
                raise TypeError("Missing required property 'd_b_instance_class'")
            __props__.__dict__["d_b_instance_class"] = d_b_instance_class
            __props__.__dict__["d_b_instance_identifier"] = d_b_instance_identifier
            __props__.__dict__["d_b_name"] = d_b_name
            __props__.__dict__["d_b_parameter_group_name"] = d_b_parameter_group_name
            __props__.__dict__["d_b_security_groups"] = d_b_security_groups
            __props__.__dict__["d_b_snapshot_identifier"] = d_b_snapshot_identifier
            __props__.__dict__["d_b_subnet_group_name"] = d_b_subnet_group_name
            __props__.__dict__["delete_automated_backups"] = delete_automated_backups
            __props__.__dict__["deletion_protection"] = deletion_protection
            __props__.__dict__["domain"] = domain
            __props__.__dict__["domain_iam_role_name"] = domain_iam_role_name
            __props__.__dict__["enable_cloudwatch_logs_exports"] = enable_cloudwatch_logs_exports
            __props__.__dict__["enable_iam_database_authentication"] = enable_iam_database_authentication
            __props__.__dict__["enable_performance_insights"] = enable_performance_insights
            __props__.__dict__["endpoint_address"] = endpoint_address
            __props__.__dict__["endpoint_port"] = endpoint_port
            __props__.__dict__["engine"] = engine
            __props__.__dict__["engine_version"] = engine_version
            __props__.__dict__["iops"] = iops
            __props__.__dict__["kms_key_id"] = kms_key_id
            __props__.__dict__["license_model"] = license_model
            __props__.__dict__["master_user_password"] = master_user_password
            __props__.__dict__["master_username"] = master_username
            __props__.__dict__["max_allocated_storage"] = max_allocated_storage
            __props__.__dict__["monitoring_interval"] = monitoring_interval
            __props__.__dict__["monitoring_role_arn"] = monitoring_role_arn
            __props__.__dict__["multi_az"] = multi_az
            __props__.__dict__["option_group_name"] = option_group_name
            __props__.__dict__["performance_insights_kms_key_id"] = performance_insights_kms_key_id
            __props__.__dict__["performance_insights_retention_period"] = performance_insights_retention_period
            __props__.__dict__["port"] = port
            __props__.__dict__["preferred_backup_window"] = preferred_backup_window
            __props__.__dict__["preferred_maintenance_window"] = preferred_maintenance_window
            __props__.__dict__["processor_features"] = processor_features
            __props__.__dict__["promotion_tier"] = promotion_tier
            __props__.__dict__["publicly_accessible"] = publicly_accessible
            __props__.__dict__["source_db_instance_identifier"] = source_db_instance_identifier
            __props__.__dict__["source_region"] = source_region
            __props__.__dict__["storage_encrypted"] = storage_encrypted
            __props__.__dict__["storage_type"] = storage_type
            __props__.__dict__["tags"] = tags
            __props__.__dict__["timezone"] = timezone
            __props__.__dict__["use_default_processor_features"] = use_default_processor_features
            __props__.__dict__["v_pc_security_groups"] = v_pc_security_groups
        super(DBInstance, __self__).__init__(
            'aws-native:rds:DBInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'DBInstance':
        """
        Get an existing DBInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = DBInstanceArgs.__new__(DBInstanceArgs)

        __props__.__dict__["allocated_storage"] = None
        __props__.__dict__["allow_major_version_upgrade"] = None
        __props__.__dict__["associated_roles"] = None
        __props__.__dict__["auto_minor_version_upgrade"] = None
        __props__.__dict__["availability_zone"] = None
        __props__.__dict__["backup_retention_period"] = None
        __props__.__dict__["c_a_certificate_identifier"] = None
        __props__.__dict__["character_set_name"] = None
        __props__.__dict__["copy_tags_to_snapshot"] = None
        __props__.__dict__["d_b_cluster_identifier"] = None
        __props__.__dict__["d_b_instance_class"] = None
        __props__.__dict__["d_b_instance_identifier"] = None
        __props__.__dict__["d_b_name"] = None
        __props__.__dict__["d_b_parameter_group_name"] = None
        __props__.__dict__["d_b_security_groups"] = None
        __props__.__dict__["d_b_snapshot_identifier"] = None
        __props__.__dict__["d_b_subnet_group_name"] = None
        __props__.__dict__["delete_automated_backups"] = None
        __props__.__dict__["deletion_protection"] = None
        __props__.__dict__["domain"] = None
        __props__.__dict__["domain_iam_role_name"] = None
        __props__.__dict__["enable_cloudwatch_logs_exports"] = None
        __props__.__dict__["enable_iam_database_authentication"] = None
        __props__.__dict__["enable_performance_insights"] = None
        __props__.__dict__["endpoint_address"] = None
        __props__.__dict__["endpoint_port"] = None
        __props__.__dict__["engine"] = None
        __props__.__dict__["engine_version"] = None
        __props__.__dict__["iops"] = None
        __props__.__dict__["kms_key_id"] = None
        __props__.__dict__["license_model"] = None
        __props__.__dict__["master_user_password"] = None
        __props__.__dict__["master_username"] = None
        __props__.__dict__["max_allocated_storage"] = None
        __props__.__dict__["monitoring_interval"] = None
        __props__.__dict__["monitoring_role_arn"] = None
        __props__.__dict__["multi_az"] = None
        __props__.__dict__["option_group_name"] = None
        __props__.__dict__["performance_insights_kms_key_id"] = None
        __props__.__dict__["performance_insights_retention_period"] = None
        __props__.__dict__["port"] = None
        __props__.__dict__["preferred_backup_window"] = None
        __props__.__dict__["preferred_maintenance_window"] = None
        __props__.__dict__["processor_features"] = None
        __props__.__dict__["promotion_tier"] = None
        __props__.__dict__["publicly_accessible"] = None
        __props__.__dict__["source_db_instance_identifier"] = None
        __props__.__dict__["source_region"] = None
        __props__.__dict__["storage_encrypted"] = None
        __props__.__dict__["storage_type"] = None
        __props__.__dict__["tags"] = None
        __props__.__dict__["timezone"] = None
        __props__.__dict__["use_default_processor_features"] = None
        __props__.__dict__["v_pc_security_groups"] = None
        return DBInstance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allocatedStorage")
    def allocated_storage(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "allocated_storage")

    @property
    @pulumi.getter(name="allowMajorVersionUpgrade")
    def allow_major_version_upgrade(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "allow_major_version_upgrade")

    @property
    @pulumi.getter(name="associatedRoles")
    def associated_roles(self) -> pulumi.Output[Optional[Sequence['outputs.DBInstanceDBInstanceRole']]]:
        return pulumi.get(self, "associated_roles")

    @property
    @pulumi.getter(name="autoMinorVersionUpgrade")
    def auto_minor_version_upgrade(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "auto_minor_version_upgrade")

    @property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "availability_zone")

    @property
    @pulumi.getter(name="backupRetentionPeriod")
    def backup_retention_period(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "backup_retention_period")

    @property
    @pulumi.getter(name="cACertificateIdentifier")
    def c_a_certificate_identifier(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "c_a_certificate_identifier")

    @property
    @pulumi.getter(name="characterSetName")
    def character_set_name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "character_set_name")

    @property
    @pulumi.getter(name="copyTagsToSnapshot")
    def copy_tags_to_snapshot(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "copy_tags_to_snapshot")

    @property
    @pulumi.getter(name="dBClusterIdentifier")
    def d_b_cluster_identifier(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "d_b_cluster_identifier")

    @property
    @pulumi.getter(name="dBInstanceClass")
    def d_b_instance_class(self) -> pulumi.Output[str]:
        return pulumi.get(self, "d_b_instance_class")

    @property
    @pulumi.getter(name="dBInstanceIdentifier")
    def d_b_instance_identifier(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "d_b_instance_identifier")

    @property
    @pulumi.getter(name="dBName")
    def d_b_name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "d_b_name")

    @property
    @pulumi.getter(name="dBParameterGroupName")
    def d_b_parameter_group_name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "d_b_parameter_group_name")

    @property
    @pulumi.getter(name="dBSecurityGroups")
    def d_b_security_groups(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "d_b_security_groups")

    @property
    @pulumi.getter(name="dBSnapshotIdentifier")
    def d_b_snapshot_identifier(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "d_b_snapshot_identifier")

    @property
    @pulumi.getter(name="dBSubnetGroupName")
    def d_b_subnet_group_name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "d_b_subnet_group_name")

    @property
    @pulumi.getter(name="deleteAutomatedBackups")
    def delete_automated_backups(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "delete_automated_backups")

    @property
    @pulumi.getter(name="deletionProtection")
    def deletion_protection(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "deletion_protection")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="domainIAMRoleName")
    def domain_iam_role_name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "domain_iam_role_name")

    @property
    @pulumi.getter(name="enableCloudwatchLogsExports")
    def enable_cloudwatch_logs_exports(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "enable_cloudwatch_logs_exports")

    @property
    @pulumi.getter(name="enableIAMDatabaseAuthentication")
    def enable_iam_database_authentication(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "enable_iam_database_authentication")

    @property
    @pulumi.getter(name="enablePerformanceInsights")
    def enable_performance_insights(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "enable_performance_insights")

    @property
    @pulumi.getter(name="endpointAddress")
    def endpoint_address(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "endpoint_address")

    @property
    @pulumi.getter(name="endpointPort")
    def endpoint_port(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "endpoint_port")

    @property
    @pulumi.getter
    def engine(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter(name="engineVersion")
    def engine_version(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "engine_version")

    @property
    @pulumi.getter
    def iops(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "iops")

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "kms_key_id")

    @property
    @pulumi.getter(name="licenseModel")
    def license_model(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "license_model")

    @property
    @pulumi.getter(name="masterUserPassword")
    def master_user_password(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "master_user_password")

    @property
    @pulumi.getter(name="masterUsername")
    def master_username(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "master_username")

    @property
    @pulumi.getter(name="maxAllocatedStorage")
    def max_allocated_storage(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "max_allocated_storage")

    @property
    @pulumi.getter(name="monitoringInterval")
    def monitoring_interval(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "monitoring_interval")

    @property
    @pulumi.getter(name="monitoringRoleArn")
    def monitoring_role_arn(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "monitoring_role_arn")

    @property
    @pulumi.getter(name="multiAZ")
    def multi_az(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "multi_az")

    @property
    @pulumi.getter(name="optionGroupName")
    def option_group_name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "option_group_name")

    @property
    @pulumi.getter(name="performanceInsightsKMSKeyId")
    def performance_insights_kms_key_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "performance_insights_kms_key_id")

    @property
    @pulumi.getter(name="performanceInsightsRetentionPeriod")
    def performance_insights_retention_period(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "performance_insights_retention_period")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="preferredBackupWindow")
    def preferred_backup_window(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "preferred_backup_window")

    @property
    @pulumi.getter(name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "preferred_maintenance_window")

    @property
    @pulumi.getter(name="processorFeatures")
    def processor_features(self) -> pulumi.Output[Optional[Sequence['outputs.DBInstanceProcessorFeature']]]:
        return pulumi.get(self, "processor_features")

    @property
    @pulumi.getter(name="promotionTier")
    def promotion_tier(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "promotion_tier")

    @property
    @pulumi.getter(name="publiclyAccessible")
    def publicly_accessible(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "publicly_accessible")

    @property
    @pulumi.getter(name="sourceDBInstanceIdentifier")
    def source_db_instance_identifier(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "source_db_instance_identifier")

    @property
    @pulumi.getter(name="sourceRegion")
    def source_region(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "source_region")

    @property
    @pulumi.getter(name="storageEncrypted")
    def storage_encrypted(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "storage_encrypted")

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "storage_type")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence['outputs.DBInstanceTag']]]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def timezone(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "timezone")

    @property
    @pulumi.getter(name="useDefaultProcessorFeatures")
    def use_default_processor_features(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "use_default_processor_features")

    @property
    @pulumi.getter(name="vPCSecurityGroups")
    def v_pc_security_groups(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "v_pc_security_groups")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'LicenseBorrowConfigurationArgs',
    'LicenseConsumptionConfigurationArgs',
    'LicenseEntitlementArgs',
    'LicenseIssuerDataArgs',
    'LicenseMetadataArgs',
    'LicenseProvisionalConfigurationArgs',
    'LicenseValidityDateFormatArgs',
]

@pulumi.input_type
class LicenseBorrowConfigurationArgs:
    def __init__(__self__, *,
                 allow_early_check_in: pulumi.Input[bool],
                 max_time_to_live_in_minutes: pulumi.Input[int]):
        pulumi.set(__self__, "allow_early_check_in", allow_early_check_in)
        pulumi.set(__self__, "max_time_to_live_in_minutes", max_time_to_live_in_minutes)

    @property
    @pulumi.getter(name="allowEarlyCheckIn")
    def allow_early_check_in(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "allow_early_check_in")

    @allow_early_check_in.setter
    def allow_early_check_in(self, value: pulumi.Input[bool]):
        pulumi.set(self, "allow_early_check_in", value)

    @property
    @pulumi.getter(name="maxTimeToLiveInMinutes")
    def max_time_to_live_in_minutes(self) -> pulumi.Input[int]:
        return pulumi.get(self, "max_time_to_live_in_minutes")

    @max_time_to_live_in_minutes.setter
    def max_time_to_live_in_minutes(self, value: pulumi.Input[int]):
        pulumi.set(self, "max_time_to_live_in_minutes", value)


@pulumi.input_type
class LicenseConsumptionConfigurationArgs:
    def __init__(__self__, *,
                 borrow_configuration: Optional[pulumi.Input['LicenseBorrowConfigurationArgs']] = None,
                 provisional_configuration: Optional[pulumi.Input['LicenseProvisionalConfigurationArgs']] = None,
                 renew_type: Optional[pulumi.Input[str]] = None):
        if borrow_configuration is not None:
            pulumi.set(__self__, "borrow_configuration", borrow_configuration)
        if provisional_configuration is not None:
            pulumi.set(__self__, "provisional_configuration", provisional_configuration)
        if renew_type is not None:
            pulumi.set(__self__, "renew_type", renew_type)

    @property
    @pulumi.getter(name="borrowConfiguration")
    def borrow_configuration(self) -> Optional[pulumi.Input['LicenseBorrowConfigurationArgs']]:
        return pulumi.get(self, "borrow_configuration")

    @borrow_configuration.setter
    def borrow_configuration(self, value: Optional[pulumi.Input['LicenseBorrowConfigurationArgs']]):
        pulumi.set(self, "borrow_configuration", value)

    @property
    @pulumi.getter(name="provisionalConfiguration")
    def provisional_configuration(self) -> Optional[pulumi.Input['LicenseProvisionalConfigurationArgs']]:
        return pulumi.get(self, "provisional_configuration")

    @provisional_configuration.setter
    def provisional_configuration(self, value: Optional[pulumi.Input['LicenseProvisionalConfigurationArgs']]):
        pulumi.set(self, "provisional_configuration", value)

    @property
    @pulumi.getter(name="renewType")
    def renew_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "renew_type")

    @renew_type.setter
    def renew_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renew_type", value)


@pulumi.input_type
class LicenseEntitlementArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 unit: pulumi.Input[str],
                 allow_check_in: Optional[pulumi.Input[bool]] = None,
                 max_count: Optional[pulumi.Input[int]] = None,
                 overage: Optional[pulumi.Input[bool]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "unit", unit)
        if allow_check_in is not None:
            pulumi.set(__self__, "allow_check_in", allow_check_in)
        if max_count is not None:
            pulumi.set(__self__, "max_count", max_count)
        if overage is not None:
            pulumi.set(__self__, "overage", overage)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def unit(self) -> pulumi.Input[str]:
        return pulumi.get(self, "unit")

    @unit.setter
    def unit(self, value: pulumi.Input[str]):
        pulumi.set(self, "unit", value)

    @property
    @pulumi.getter(name="allowCheckIn")
    def allow_check_in(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "allow_check_in")

    @allow_check_in.setter
    def allow_check_in(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allow_check_in", value)

    @property
    @pulumi.getter(name="maxCount")
    def max_count(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "max_count")

    @max_count.setter
    def max_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_count", value)

    @property
    @pulumi.getter
    def overage(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "overage")

    @overage.setter
    def overage(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "overage", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class LicenseIssuerDataArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 sign_key: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "name", name)
        if sign_key is not None:
            pulumi.set(__self__, "sign_key", sign_key)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="signKey")
    def sign_key(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "sign_key")

    @sign_key.setter
    def sign_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sign_key", value)


@pulumi.input_type
class LicenseMetadataArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 value: pulumi.Input[str]):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class LicenseProvisionalConfigurationArgs:
    def __init__(__self__, *,
                 max_time_to_live_in_minutes: pulumi.Input[int]):
        pulumi.set(__self__, "max_time_to_live_in_minutes", max_time_to_live_in_minutes)

    @property
    @pulumi.getter(name="maxTimeToLiveInMinutes")
    def max_time_to_live_in_minutes(self) -> pulumi.Input[int]:
        return pulumi.get(self, "max_time_to_live_in_minutes")

    @max_time_to_live_in_minutes.setter
    def max_time_to_live_in_minutes(self, value: pulumi.Input[int]):
        pulumi.set(self, "max_time_to_live_in_minutes", value)


@pulumi.input_type
class LicenseValidityDateFormatArgs:
    def __init__(__self__, *,
                 begin: pulumi.Input[str],
                 end: pulumi.Input[str]):
        """
        :param pulumi.Input[str] begin: Validity begin date for the license.
        :param pulumi.Input[str] end: Validity begin date for the license.
        """
        pulumi.set(__self__, "begin", begin)
        pulumi.set(__self__, "end", end)

    @property
    @pulumi.getter
    def begin(self) -> pulumi.Input[str]:
        """
        Validity begin date for the license.
        """
        return pulumi.get(self, "begin")

    @begin.setter
    def begin(self, value: pulumi.Input[str]):
        pulumi.set(self, "begin", value)

    @property
    @pulumi.getter
    def end(self) -> pulumi.Input[str]:
        """
        Validity begin date for the license.
        """
        return pulumi.get(self, "end")

    @end.setter
    def end(self, value: pulumi.Input[str]):
        pulumi.set(self, "end", value)


